/SPECIES: Collective Sorting Robots
/AUTHORS: Alexis Drogoul
/DATE:    07/02/96
/VERSION: 1.5
/
BEGIN CLASSES
Collective Sorting Robots
EggClass = EggAgent
LarvaClass = LarvaAgent
CocoonClass = CocoonAgent
AntClass = AntAgent
QueenClass = QueenAgent
END CLASSES
/
/This file describes the  parameters used to model
/simple robots able to collectively sort objects (in fact: eggs, larvae, cocoons). These parameters are intented
/to be used by the agents during the simulation.
/
/Each parameter is described as following:
/
/   AgentClass.parameterName = value of the parameter (Integer or Real)
/   /unit: ... (description of the value unit)
/   /comment: ... (any comment you wish to add)
/
/General parameters can also be provided, with AgentClass being replaced
/by the keyword "Simulation".
/
/Comments, extra-information and blank lines have to be preceded by "/",
/otherwise this may lead to an error at run-time. The beginning of the file
/has to be preceded by the keyword "BEGIN SPECIES" (obvious!), and its end by ... "END SPECIES".
/
/Do not modify an existing file without saving it with an other name.
/
BEGIN SPECIES PROPERTIES
/
/                           General Parameters
/
Simulation.foodPerAgent = 0
/unit: number of agents
/comment: number of FoodAgent being distributed to each ant (workers + queens)
/
Simulation.feedingTime = 1000000
/unit: cycles (1 day ~ 12000 cyles)
/comment: interval between two distributions of food to the colony
/
/
/                           AntAgent
/
AntAgent.maturingTimeBase = 6000000
/unit: cycles (1 day ~ 12000 cycles)
/comment: max. number of cycles a worker can live.
/
AntAgent.maturingTimeDelta = 0
/unit: cycles (1 day ~ 12000 cycles)
/
AntAgent.maxFoodLevel = 30
/unit: food units (see FoodAgent)
/comment: max. number of food units a worker can be fed with
/
AntAgent.minFoodLevel = 3
/unit: food units (see FoodAgent)
/comment: min. number of food units before beginnning to starve
/
AntAgent.maxCureLevel = 30
/unit: cure units (number of cure acts)
/comment: max. number of cure acts a worker needs to receive
/
AntAgent.minCureLevel = 0
/unit: cure units (number of cure acts)
/
AntAgent.voracity = 0.00
/unit: food units per cycle
/comment: amount of food being consumed at each cycle by a worker
/
AntAgent.wastingAway = 0.00
/unit: cure units per cycle
/comment: describes the decrease of the cure level at each cycle
AntAgent.carryingCapacity = 1
/
/                               QueenAgent (inherits from AntAgent)
/
QueenAgent.layEggsTime = 6776
/unit: cycles
/comment: interval of time between two egg layings
/
/                               EggAgent
/
EggAgent.maturingTimeBase = 6000000
/unit: cycles (1 day ~ 12000 cycles)
/comment: base number of cycles an egg can live.
/
EggAgent.maturingTimeDelta = 0
/unit: cycles (1 day ~ 12000 cycles)
/comment: number of cycles being randomly added or removed to the base number.
/
EggAgent.maxFoodLevel = 10
EggAgent.minFoodLevel = 0
EggAgent.maxCureLevel = 30
EggAgent.minCureLevel = 0
EggAgent.voracity = 0
EggAgent.wastingAway = 0.00
/
/                               CocoonAgent
/
CocoonAgent.maturingTimeBase = 6000000
CocoonAgent.maturingTimeDelta = 0
CocoonAgent.maxFoodLevel = 10
CocoonAgent.minFoodLevel = 0
CocoonAgent.maxCureLevel = 30
CocoonAgent.minCureLevel = 0
CocoonAgent.voracity = 0
CocoonAgent.wastingAway = 0.000
/
/                               LarvaAgent
/
LarvaAgent.maturingTimeBase = 6000000
LarvaAgent.maturingTimeDelta = 0
LarvaAgent.maturingTimeLimit = 6000000
LarvaAgent.maxFoodLevel = 30
LarvaAgent.minFoodLevel = 3
LarvaAgent.maxCureLevel = 30
LarvaAgent.minCureLevel = 0
LarvaAgent.voracity = 0.00
LarvaAgent.wastingAway = 0.00
/
/                               FoodAgent
/ FoodAgent is usually not dependent on the species.
/ However, it is possible to modify some values here.
/
FoodAgent.maturingTime = 25000
FoodAgent.maxFoodLevel = 30
FoodAgent.minFoodLevel = 0
FoodAgent.maxCureLevel = 30
FoodAgent.minCureLevel = 0
FoodAgent.voracity = 0
FoodAgent.wastingAway = 0
FoodAgent.decrementTime = 1000
/unit: cycles
/comment: interval of time between two decrements of the agent by one unit.
END SPECIES PROPERTIES

BEGIN SPECIES TASKS

class AntAgent

	task egg
	weight 4
	threshold 15
	behavior
		repeat follow(egg)
		do carry(egg)
		repeat follow(egg)
	interrupt 
		do putDown(egg)
	end egg

	task larva
	weight 4
	threshold 15
	behavior
		repeat follow(larva)
		do carry(larva)
		repeat follow(larva)
	interrupt 
		do putDown(larva)
	end larva

	task cocoon
	weight 4
	threshold 15
	behavior
		repeat follow(cocoon)
		do carry(cocoon)
		repeat follow(cocoon)
	interrupt 
		do putDown(cocoon)
	end cocoon

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior 
		repeat move()
	end default
endClass AntAgent

class EggAgent

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior
		repeat propagate()
	end default

endClass EggAgent

class CocoonAgent

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior
		repeat propagate()
	end default

endClass CocoonAgent

class LarvaAgent

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior
		repeat propagate()
	end default

endClass LarvaAgent

class QueenAgent

	task egg
	weight 4
	threshold 15
	behavior
		repeat follow(egg)
		do carry(egg)
		repeat follow(egg)
	interrupt 
		do putDown(egg)
	end egg

	task larva
		weight 4
		threshold 15
		behavior
			repeat follow(larva)
			do carry(larva)
			repeat follow(larva)
		interrupt 
			do putDown(larva)
	end larva

	task cocoon
		weight 4
		threshold 15
		behavior
			repeat follow(cocoon)
			do carry(cocoon)
			repeat follow(cocoon)
		interrupt 
			do putDown(cocoon)
	end cocoon

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior 
		repeat move()
	end default

endClass QueenAgent


END SPECIES TASKS
