/SPECIES: Ectatomma Ruidum Roger
/AUTHORS: Alexis Drogoul, Dominique Fresneau, Bruno Corbara
/DATE:    30/10/95
/VERSION: 1.5
/
/The next lines (between 'BEGIN CLASSES' and 'END CLASSES')
/provide the simulation with very important information, such
/as the object classes to be used.
/Do not modify them unless you know what you are doing...
BEGIN CLASSES
Ectatomma Ruidum Roger
EggClass = EggAgent
LarvaClass = LarvaAgent
CocoonClass = CocoonAgent
AntClass = AntAgent
QueenClass = QueenAgent
END CLASSES
/
/This file describes the biological parameters used to model
/Ectatomma Ruidum Rogers ants. These parameters are intented
/to be used by the agents during the simulation.
/
/Each parameter is described as following:
/
/   AgentClass.parameterName = value of the parameter (Integer or Real)
/   /unit: ... (description of the value unit)
/   /comment: ... (any comment you wish to add)
/
/General parameters can also be provided, with AgentClass being replaced
/by the keyword "Simulation".
/
/Comments, extra-information and blank lines have to be preceded by "/",
/otherwise this may lead to an error at run-time. The beginning of the file
/has to be preceded by the keyword "BEGIN SPECIES" (obvious!), and its end by ... "END SPECIES".
/
/Do not modify an existing file without saving it with an other name.
/
BEGIN SPECIES PROPERTIES
/
/                           General Parameters
/
Simulation.foodPerAgent = 8
/unit: number of agents
/comment: number of FoodAgent being distributed to each ant (workers + queens)
/
Simulation.feedingTime = 26000
/unit: cycles (1 day ~ 12000 cyles)
/comment: interval between two distributions of food to the colony
/
/
/                           AntAgent
/
AntAgent.maturingTimeBase = 6000000
/unit: cycles (1 day ~ 12000 cycles)
/comment: max. number of cycles a worker can live.
/
AntAgent.maturingTimeDelta = 0
/unit: cycles (1 day ~ 12000 cycles)
/
AntAgent.maxFoodLevel = 30
/unit: food units (see FoodAgent)
/comment: max. number of food units a worker can be fed with
/
AntAgent.minFoodLevel = 3
/unit: food units (see FoodAgent)
/comment: min. number of food units before beginnning to starve
/
AntAgent.maxCureLevel = 30
/unit: cure units (number of cure acts)
/comment: max. number of cure acts a worker needs to receive
/
AntAgent.minCureLevel = 0
/unit: cure units (number of cure acts)
/
AntAgent.voracity = 0.002
/unit: food units per cycle
/comment: amount of food being consumed at each cycle by a worker
/
AntAgent.wastingAway = 0.002
/unit: cure units per cycle
/comment: describes the decrease of the cure level at each cycle
/
/                               QueenAgent (inherits from AntAgent)
/
QueenAgent.layEggsTime = 6776
/unit: cycles
/comment: interval of time between two egg layings
/
QueenAgent.voracity = 0.0025
/unit: food units per cycle
/comment: amount of food being consumed at each cycle by a queen
/
/                               EggAgent
/
EggAgent.maturingTimeBase = 253440
/unit: cycles (1 day ~ 12000 cycles)
/comment: base number of cycles an egg can live.
/
EggAgent.maturingTimeDelta = 3840
/unit: cycles (1 day ~ 12000 cycles)
/comment: number of cycles being randomly added or removed to the base number.
/
EggAgent.maxFoodLevel = 10
EggAgent.minFoodLevel = 0
EggAgent.maxCureLevel = 30
EggAgent.minCureLevel = 0
EggAgent.voracity = 0
EggAgent.wastingAway = 0.003
/
/                               CocoonAgent
/
CocoonAgent.maturingTimeBase = 334080
CocoonAgent.maturingTimeDelta = 46080
CocoonAgent.maxFoodLevel = 10
CocoonAgent.minFoodLevel = 0
CocoonAgent.maxCureLevel = 30
CocoonAgent.minCureLevel = 0
CocoonAgent.voracity = 0
CocoonAgent.wastingAway = 0.0005
/
/                               LarvaAgent
/
LarvaAgent.maturingTimeBase = 212428
LarvaAgent.maturingTimeDelta = 11520
LarvaAgent.maturingTimeLimit = 253440
LarvaAgent.maxFoodLevel = 30
LarvaAgent.minFoodLevel = 3
LarvaAgent.maxCureLevel = 30
LarvaAgent.minCureLevel = 0
LarvaAgent.voracity = 0.002
LarvaAgent.wastingAway = 0.002
/
/                               FoodAgent
/ FoodAgent is usually not dependent on the species.
/ However, it is possible to modify some values here.
/
FoodAgent.maturingTime = 25000
FoodAgent.maxFoodLevel = 30
FoodAgent.minFoodLevel = 0
FoodAgent.maxCureLevel = 30
FoodAgent.minCureLevel = 0
FoodAgent.voracity = 0
FoodAgent.wastingAway = 0
FoodAgent.decrementTime = 1000
/unit: cycles
/comment: interval of time between two decrements of the agent by one unit.
END SPECIES PROPERTIES

BEGIN SPECIES TASKS

class AntAgent

	task egg
	weight 4
	threshold 15
	behavior
		repeat follow(egg)
		do carry(egg)
		repeat follow(egg humidity -larva)
	interrupt 
		do putDown(egg)
	end egg

	task larva
	weight 4
	threshold 15
	behavior
		repeat follow(larva)
		do carry(larva)
		repeat follow(-egg humidity larva -light)
	interrupt 
		do putDown(larva)
	end larva

	task cocoon
	weight 4
	threshold 15
	behavior
		repeat follow(cocoon)
		do carry(cocoon)
		repeat follow(cocoon -humidity -light)
	interrupt 
		do putDown(cocoon)
	end cocoon

	task cureLarva
	weight 16
	threshold 60
	behavior
		repeat follow(cureLarva)
		repeat cure(cureLarva)
	end cureLarva

	task cureEgg
	weight 8
	threshold 30
	behavior
		repeat follow(cureEgg)
		repeat cure(cureEgg)
	end cureEgg

	task cureCocoon
	weight 48
	threshold 180
	behavior
		repeat follow(cureCocoon)
		repeat cure(cureCocoon)
	end cureCocoon

	task cureAnt
	weight 8
	threshold 30
	behavior
		repeat cure()
	end cureAnt

	task maturingEgg
	weight 4
	threshold 15
	behavior
		repeat follow(maturingEgg)
		do carry(maturingEgg)
		repeat follow(humidity larva -light)
	interrupt 
		do putDown(egg)
	end maturingEgg

	task maturingLarva
	weight 4
	threshold 15
	behavior
		repeat follow(maturingLarva)
		do carry(maturingLarva)
		repeat follow(-larva cocoon -humidity)
	interrupt 
		do putDown(larva)
	end maturingLarva

	task maturingCocoon
	weight 4
	threshold 15
	behavior
		repeat follow(maturingCocoon)
		repeat cure(maturingCocoon)
	end maturingCocoon

	task maturingAnt
	weight 4
	threshold 15
	behavior
		do mature()
	end maturingAnt

	task hungryLarva
	weight 4
	threshold 15
	behavior
		repeat follow(locFood food)
		do carryOne(food)
		repeat follow(hungryLarva humidity)
	interrupt
		do putDown(food)
	end hungryLarva
		
	task hungryAnt
	weight 2
	threshold 15
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat follow(locFood food)
		repeat eat(food)
	end hungryAnt

	task killEgg
	weight 4
	threshold 15
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat follow(locEgg)
		do kill(egg)
	end killEgg

	task killLarva
	weight 10
	threshold 20
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat follow(locLarva hungryLarva)
		do kill(larva)
	end killLarva

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior 
		repeat move()
	end default

	task food
	weight 4
	threshold 100
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat follow(food)
		repeat eat(food)
		do carryOne(food)
		repeat follow(humidity)
	interrupt
		do putDown(food)
	end food

	task light
	weight 0.75
	threshold 10
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat follow(humidity -light)
	end light

endClass AntAgent

class EggAgent

	task maturingEgg
	weight 4
	threshold 15
	behavior
		do mature()
	end maturingEgg

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior
		repeat propagate()
	end default

endClass EggAgent

class CocoonAgent

	task maturingCocoon
	weight 4
	threshold 15
	behavior
		do mature()
	end maturingCocoon

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior
		repeat propagate()
	end default

endClass CocoonAgent

class LarvaAgent

	task maturingLarva
	weight 4
	threshold 15
	behavior
		do mature()
	end maturingLarva

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior
		repeat propagate()
	end default

	task hungryLarva
	weight 4
	threshold 4
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat eat(food)
		do propagate()
	end hungryLarva

endClass LarvaAgent

class QueenAgent

	task killEgg
	weight 4
	threshold 15
	weightIncrement 0
	thresholdIncrement 0
	behavior
		repeat follow(locEgg)
		do kill(egg)
	end killEgg

	task maturingEgg
	weight 4
	threshold 15
	behavior
		repeat follow(maturingEgg)
		do carry(maturingEgg)
		repeat follow(humidity larva -light)
	interrupt 
		do putDown(egg)
	end maturingEgg

	task maturingLarva
	weight 4
	threshold 15
	behavior
		repeat follow(maturingLarva)
		do carry(maturingLarva)
		repeat follow(-larva cocoon -humidity)
	interrupt 
		do putDown(larva)
	end maturingLarva

	task maturingCocoon
	weight 4
	threshold 15
	behavior
		repeat follow(maturingCocoon)
		repeat cure(maturingCocoon)
	end maturingCocoon

	task egg
	weight 4
	threshold 15
	behavior
		repeat follow(egg)
		do carry(egg)
		repeat follow(egg humidity -larva)
	interrupt 
		do putDown(egg)
	end egg

	task larva
		weight 4
		threshold 15
		behavior
			repeat follow(larva)
			do carry(larva)
			repeat follow(-egg humidity larva -light)
		interrupt 
			do putDown(larva)
	end larva

	task cocoon
		weight 4
		threshold 15
		behavior
			repeat follow(cocoon)
			do carry(cocoon)
			repeat follow(cocoon -humidity -light)
		interrupt 
			do putDown(cocoon)
	end cocoon

	task cureLarva
		weight 16
		threshold 60
		behavior
			repeat follow(cureLarva)
			repeat cure(cureLarva)
	end cureLarva

	task cureEgg
		weight 8
		threshold 30
		behavior
			repeat follow(cureEgg)
			repeat cure(cureEgg)
	end cureEgg

	task cureCocoon
		weight 48
		threshold 180
		behavior
			repeat follow(cureCocoon)
			repeat cure(cureCocoon)
	end cureCocoon

	task killLarva
		weight 10
		threshold 20
		weightIncrement 0
		thresholdIncrement 0
		behavior
			repeat follow(locLarva hungryLarva)
			do kill(larva)
	end killLarva

	task hungryLarva
		weight 4
		threshold 15
		behavior
			repeat follow(locFood food)
			do carryOne(food)
			repeat follow(hungryLarva humidity)
		interrupt
			do putDown(food)
	end hungryLarva

	task default
	weight 1
	threshold 0
	weightIncrement 0
	activityLevelDecrement 0
	behavior 
		repeat move()
	end default

	task food
		weight 4
		threshold 100
		weightIncrement 0
		thresholdIncrement 0
		behavior
			repeat follow(food)
			repeat eat(food)
			do carryOne(food)
			repeat follow(humidity)
		interrupt
			do putDown(food)
	end food

	task layEggsQueen
		weight 4
		threshold 15
		behavior
			repeat follow(humidity egg cureEgg)
			do layEgg()
	end layEggsQueen

	task cureQueen
		weight 8
		threshold 30
		behavior
			repeat cure()
	end cureQueen

	task hungryQueen
		weight 2
		threshold 15
		weightIncrement 0
		thresholdIncrement 0
		behavior
			repeat follow(locFood food)
			repeat eat(food)
	end hungryQueen

	task maturingQueen
		weight 4
		threshold 15
		behavior
			do mature()
	end maturingQueen

	task light
		weight 1.5
		threshold 10
		weightIncrement 0
		thresholdIncrement 0
		behavior
			repeat follow(humidity -light)
	end light

endClass QueenAgent


END SPECIES TASKS
